#[non_exhaustive]
pub enum ExpressionParseErrorKind {
InvalidNot(usize),
InvalidCharacters,
UnclosedParens,
UnopenedParens,
UnclosedQuotes,
UnopenedQuotes,
Empty,
Unexpected {
expected: &'static [&'static str],
},
InvalidInteger,
MultipleRootPredicates,
InvalidHasAtomic,
UnknownBuiltin,
}Expand description
The kind of ExpressionParseError that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidNot(usize)
not() takes exactly 1 predicate, unlike all() and any()
InvalidCharacters
The characters are not valid in an cfg expression
UnclosedParens
An opening parens was unmatched with a closing parens
UnopenedParens
A closing parens was unmatched with an opening parens
UnclosedQuotes
An opening quotes was unmatched with a closing quotes
UnopenedQuotes
A closing quotes was unmatched with an opening quotes
Empty
The expression does not contain any valid terms
Unexpected
Fields
expected: &'static [&'static str]The list of expected terms.
Found an unexpected term, which wasn’t one of the expected terms that is listed
InvalidInteger
Failed to parse an integer value
MultipleRootPredicates
The root cfg() may only contain a single predicate
InvalidHasAtomic
A target_has_atomic predicate didn’t correctly parse.
UnknownBuiltin
An element was not part of the builtin information in rustc